.. lavuelib documentation master file, created by
   sphinx-quickstart on Thu Jan 25 15:05:39 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

  .. default-domain:: py
		       
.. include:: ../README.rst
				 
Contents
========

.. toctree::
   :maxdepth: 4

   lavuelib


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

